==> fwobac-1.2.tar.gz: fwobac-1.2/mail.h <==
/*	$Id: mail.h,v 1.5 2017/08/01 10:54:17 rlr Exp $ */

/*
 * Copyright (c) 2004-2006 Daniel Hartmeier
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

/*
 * Reworked by Ross Richardson in 2016, 2017.
 */

#ifndef _MAIL_H_
#define _MAIL_H_


/*
 * The Mail transport agent used.  It must read a message from its standard
 * input and, when invoked with option "-t", take delivery address(es) from
 * the message (like sendmail)
 */
#define MAIL_MTA  "/bin/femail"


/* Return codes for mail_send() */
#define MAIL_ERR_NONE     0
#define MAIL_ERR_INVALID  1
#define MAIL_ERR_PIPE     2
#define MAIL_ERR_FORK     3
#define MAIL_ERR_WRITE    4
#define MAIL_ERR_WAIT     5


/* 
 * int	 mail_send(int (*cb)(const int, void *), void *a);
 *
 * Function for sending email.
 *
 * If cb is non-NULL, it is called (with a file descriptor and a) to write
 * the message body.  If cb is NULL, a must be non-NULL and is interpreted
 * as a (const) char* containing the message body.
 */
int	 mail_send(int (*)(const int, void *), void *);


#endif /* !_MAIL_H_ */

==> fwobac-2.1.tar.gz: fwobac-2.1/mail.h <==
/*	$Id: mail.h,v 1.11 2018/06/28 04:55:17 rlr Exp $ */

/*
 * Copyright (c) 2004-2006 Daniel Hartmeier
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

/*
 * Reworked in 2016-2018 by Ross Richardson <rueda@rlr.id.au>
 */

#ifndef _MAIL_H_
#define _MAIL_H_


/*
 * The Mail transport agent used.  It must read a message from its standard
 * input and, when invoked with option "-t", take delivery address(es) from
 * the message (like sendmail).
 */
#ifndef MAIL_MTA
#define MAIL_MTA  "/usr/sbin/sendmail"
#endif /* !MAIL_MTA */


/* Return codes for mail_send() */
#define MAIL_ERR_NONE     0
#define MAIL_ERR_INVALID  1
#define MAIL_ERR_PIPE     2
#define MAIL_ERR_FORK     3
#define MAIL_ERR_WRITE    4
#define MAIL_ERR_WAIT     5


/*
 * int
 * mail_send(int (*cb)(const int, void *), void *a);
 *
 * Function for sending email.
 *
 * If cb is non-NULL, it is called (with a file descriptor and a) to write
 * the message body.  If cb is NULL, a must be non-NULL and is interpreted
 * as a (const) char* containing the message body.
 */
int	 mail_send(int (*)(const int, void *), void *);


#endif /* !_MAIL_H_ */
